FsChangesArgs

Struct FsChangesArgs 

pub struct FsChangesArgs {
    pub timestamp: DInstant,
    pub changes: Arc<Vec<FsChange>>,
    pub propagation: EventPropagationHandle,
}
FS_CHANGES_EVENT arguments.

Fields

timestamp: DInstant

Instant the event happened.

changes: Arc<Vec<FsChange>>

All notify changes since the last event.

propagation: EventPropagationHandle

Propagation handle associated with this event instance.

Cloned arguments share the same handle, some arguments may also share the handle of another event if they share the same cause.

Implementations

Source

impl FsChangesArgs

pub fn new( timestamp: impl Into<DInstant>, propagation: EventPropagationHandle, changes: impl Into<Arc<Vec<FsChange>>>, ) -> Self

New args from values that convert into the argument types.

pub fn now(changes: impl Into<Arc<Vec<FsChange>>>) -> Self

Arguments for event that happened now (INSTANT.now).

Source

impl FsChangesArgs

pub fn events(&self) -> impl Iterator<Item = &Event> + '_

Iterate over all change events.

pub fn errors(&self) -> impl Iterator<Item = &Error> + '_

Iterate over all file watcher errors.

pub fn rescan(&self) -> bool

Returns true is some events where lost.

This indicates either a lapse in the events or a change in the filesystem such that events received so far can no longer be relied on to represent the state of the filesystem now.

An application that simply reacts to file changes may not care about this. An application that keeps an in-memory representation of the filesystem will need to care, and will need to refresh that representation directly from the filesystem.

pub fn changes_for( &self, glob: &str, ) -> Result<impl Iterator<Item = &FsChange> + '_, PatternError>

Iterate over all changes that affects paths selected by the glob pattern.

pub fn changes_for_path<'a>( &'a self, path: &'a Path, ) -> impl Iterator<Item = &'a FsChange> + 'a

Iterate over all changes that affects paths that are equal to path or inside it.

pub fn events_for( &self, glob: &str, ) -> Result<impl Iterator<Item = &Event> + '_, PatternError>

Iterate over all change events that affects that are equal to path or inside it.

pub fn events_for_path<'a>( &'a self, path: &'a Path, ) -> impl Iterator<Item = &'a Event> + 'a

Iterate over all change events that affects paths that are equal to path or inside it.